@@ -13,7 +13,7 @@ use Socket qw(inet_ntoa AF_INET IPPROTO_TCP);
 my $AF_INET6 = eval { Socket::AF_INET6() };
 my $NI_NUMERICHOST = eval { Socket::NI_NUMERICHOST() };
 
-our $VERSION = '0.13';
+our $VERSION = '0.15';
 our @ISA;
 
 my $HAVE_IO_Socket_IP = 0;
@@ -134,7 +134,10 @@ sub new {
                             $LASTERROR = "IO::Socket::IP required for IPv6";
                             return undef
                         }
-                        $params{Family} = $AF_INET6
+                        $params{Family} = $AF_INET6;
+                        if ($^O ne 'MSWin32') {
+                            $params{V6Only} = 1
+                        }
                     }
                 } else {
                     $LASTERROR = "Invalid family - $cfg{$_}";
@@ -147,6 +150,9 @@ sub new {
                     $LASTERROR = "Invalid timeout - $cfg{$_}";
                     return undef
                 }
+            # pass through
+            } else {
+                $params{$_} = $cfg{$_}
             }
         }
     }
@@ -226,6 +232,7 @@ sub get_trap {
     # read the message
     if ($udpserver->recv($datagram, $datagramsize)) {
 
+        $trap->{_UDPSERVER_} = $udpserver;
         $trap->{_TRAP_}{PeerPort} = $udpserver->SUPER::peerport;
         $trap->{_TRAP_}{PeerAddr} = $udpserver->SUPER::peerhost;
         $trap->{_TRAP_}{datagram} = $datagram;
@@ -496,37 +503,25 @@ sub _InformRequest_Response {
     my ($self, $trap, $pdutype) = @_;
     my $class = ref($$self) || $$self;
 
+    #DEBUG print "BUFFER = $buffer\n";
+    if (!defined $$self->{_UDPSERVER_}) {
+        return "Server not defined"
+    }
+
     # Change from request to response
     $trap->{pdu_type}{response} = delete $trap->{pdu_type}{inform_request};
-
     my $buffer = $snmpasn->encode($trap);
     if (!defined($buffer)) {
         return $snmpasn->error
     }
-    #DEBUG print "BUFFER = $buffer\n";
-    if (!defined($$self->{_TRAP_}->{PeerAddr}) || ($$self->{_TRAP_}->{PeerAddr} eq "")) {
-        return "Peer Addr undefined"
-    }
-    if (!defined($$self->{_TRAP_}->{PeerPort}) || ($$self->{_TRAP_}->{PeerPort} == 0)) {
-        return "Peer Port undefined"
-    }
 
-    my $socket = $class->SUPER::new(
-        Proto     => "udp",
-        PeerAddr  => $$self->{_TRAP_}->{PeerAddr},
-        PeerPort  => $$self->{_TRAP_}->{PeerPort},
-        # LocalPort should be set, but creates error.
-        # Tried setting ReusePort on initial server,
-        # but not implemented on Windows.  What to do?
-        #LocalPort => SNMPTRAPD_DEFAULT_PORT,
-        Family    => $$self->{Family}
-    ) || return "Can't create Response socket";
+    # send Inform response
+    my $socket = $$self->{_UDPSERVER_};
     $socket->send($buffer);
-    close $socket;
 
     # Change back to request from response
     $trap->{pdu_type}{inform_request} = delete $trap->{pdu_type}{response};
-    return ("OK")
+    return "OK"
 }
 
 sub _inetNtoa {
